import matplotlib.pyplot as plt
import numpy as np
import seaborn as sns

def get_regplot(df_main, out_name):

    var1, var2 = 'cos_avg', 'clust_cont'
    plt.rcParams.update({'font.size': 11, 'mathtext.default': 'regular' })
    labels = df_main.index.to_list()
    fig, ax = plt.subplots(ncols=2, figsize=(12, 5.5), sharey=True, 
                           gridspec_kw=dict(wspace=0.05), dpi=150)

    scatter_kws = dict(s=30, lw=0.3, alpha=1, zorder=2, ec='w')
    line_kws = dict(color='plum', zorder=1)

    l_upper = ['population', 'hesitate', 'nomination', 
               'exploration', 'reparation']
    l_lower = ['souvenir', 'exchange', 'boutique']
    l_left = ['exposition', 'animator', 
              'circulation', 'manifestation',
              'proposition',
              'definitively']

    sns.regplot(x=var1, y='human_avg', data=df_main, scatter_kws=scatter_kws, 
                ax=ax[0], line_kws=line_kws)

    coords = df_main[[var1, 'human_avg']].values
    out_labels = []

    for i, (x, y) in enumerate(coords):
        label = labels[i]

        coeff = 0.007
        if label in l_upper:
            va = 'bottom'
        elif label in l_lower:
            va = 'top'
        else:
            va = 'center'
        if label in l_left:
            ha = 'right'
            x -= coeff
        else:
            ha = 'left'
            x += coeff 

        ax[0].text(x, y, label, ha=ha, va=va)


    r_upper = ['availability', 'nomination', 'portable']
    r_left = ['definitively', 'exchange', 'souvenir']
    r_lower = ['exchange', 'affirmation', 'dossier', 'exploration', 'permit']

    sns.regplot(x=var2, y='human_avg', data=df_main, scatter_kws=scatter_kws,
                ax=ax[1], line_kws=line_kws)   

    coords = df_main[[var2, 'human_avg']].values
    for i, (x, y) in enumerate(coords):
        label = labels[i]

        coeff = 0.015
        if label in r_upper:
            va = 'bottom'
        elif label in r_lower:
            va = 'top'
        else:
            va = 'center'
        if label in r_left:
            ha = 'right'
            x -= coeff
        else:
            ha = 'left'
            x += coeff 

        ax[1].text(x, y, label, ha=ha, va=va)


    ax[0].set_xlabel('$cos_{AVG}$')
    ax[1].set_xlabel('$clust_{CONT}$')
    ax[0].set_ylabel('mean acceptability rating')
    ax[1].set_ylabel(None)
    ax[0].set_ylim(1.45, 5.8)
    ax[0].set_xlim(0.06, 0.49)
    ax[1].set_xlim(-0.02, 1.05)

    ax[1].tick_params(left=False)
    ax[0].set_xticks(np.arange(0.1, 0.5, 0.1))
    ax[0].set_yticks(np.arange(2, 6))

    for i in range(2):
        ax[i].grid(color='gainsboro')
        ax[i].set_axisbelow(True)
        
    plt.savefig(out_name, dpi=150, bbox_inches='tight')